@@ -1,18 +1,36 @@
+package Apache::Wyrd::Cookie;
 use 5.006;
 use strict;
 use warnings;
 no warnings qw(uninitialized redefine);
 
-package Apache::Wyrd::Cookie;
-our $VERSION = '0.96';
+our $VERSION = '0.97';
 use vars qw(@ISA);
 
+#set environment variables WYRD_USE_CGI or WYRD_USE_APR
+#to force the use of libapreq or CGI
+my $force_apr = 0;
+my $force_cgi = 0;
+if ($ENV{WYRD_USE_CGI}) {
+	$force_cgi = 1;
+}
+if ($ENV{WYRD_USE_APR}) {
+	$force_apr = 1;
+}
+
 my $have_apr = 1;
-eval('use Apache::Cookie');
-if ($@) {
+my $init_error = '';
+if (!$force_cgi) {
+	eval('use Apache::Cookie');
+	if ($@) {
+		$init_error = $@;
+		die "$@" if ($force_apr);
+	}
+}
+if ($init_error or $force_cgi) {
 	eval('use CGI::Cookie');
 	die "$@" if ($@);
-	$have_apr=0;
+	$have_apr = 0;
 	push @ISA, 'CGI::Cookie';
 } else {
 	push @ISA, 'Apache::Cookie';
@@ -43,12 +61,20 @@ Apache::Wyrd::Cookie - Consistency wrapper for Apache::Cookie and CGI::Cookie
 
 =head1 DESCRIPTION
 
-Wrapper for C<Apache::Cookie> or C<CGI:Cookie> cookies. This class is
-provided for no other reason than to make the C<new> and C<bake> methods
-consistent in their requirements, which they are not normally.
-Otherwise, C<Apache::Wyrd::Cookie> behaves entirely like C<Apache::Cookie>
-and takes the same arguments to its methods. Please refer to the
-documentation for that module.
+Wrapper for C<Apache::Cookie> or C<CGI:Cookie> cookies. This class is provided
+for no other reason than to make the C<new> and C<bake> methods consistent in
+their requirements between these modules, which they are not normally.
+Otherwise, C<Apache::Wyrd::Cookie> behaves entirely like C<Apache::Cookie> or
+C<CGI::Cookie> depending on which is installed and takes the same arguments to
+its methods. Please refer to the documentation for those modules.
+
+The normal behavior is to favor C<Apache::Cookie>.  If it is not installed, it
+will attempt to use CGI.  Failing both, it will call C<die()>, causing a server
+error.  You can force the use of C<Apache::Cookie> or C<CGI::Cookie> by setting
+the WYRD_USE_CGI or WYRD_USE_APR environment variables.  If the forced module
+fails to load, the module will C<die()>, causing a server error.  Note that
+using these environement variables also affects the behavior of
+C<Apache::Wyrd::Cookie>.
 
 =cut
 
